@@ -15,8 +15,8 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
+ * License along with this library. If not, see
+ * <http://www.gnu.org/licenses/>.
  *
  * Author: Daniel P. Berrange <berrange@redhat.com>
  */
@@ -43,7 +43,8 @@ enum {
     PROP_DESCRIPTION,
     PROP_MEMORY,
     PROP_VCPU,
-    PROP_FEATURES
+    PROP_FEATURES,
+    PROP_CURRENT_MEMORY
 };
 
 static void gvir_config_domain_get_property(GObject *object,
@@ -66,6 +67,9 @@ static void gvir_config_domain_get_property(GObject *object,
     case PROP_MEMORY:
         g_value_set_uint64(value, gvir_config_domain_get_memory(domain));
         break;
+    case PROP_CURRENT_MEMORY:
+        g_value_set_uint64(value, gvir_config_domain_get_current_memory(domain));
+        break;
     case PROP_VCPU:
         g_value_set_uint64(value, gvir_config_domain_get_vcpus(domain));
         break;
@@ -98,6 +102,9 @@ static void gvir_config_domain_set_property(GObject *object,
     case PROP_MEMORY:
         gvir_config_domain_set_memory(domain, g_value_get_uint64(value));
         break;
+    case PROP_CURRENT_MEMORY:
+        gvir_config_domain_set_current_memory(domain, g_value_get_uint64(value));
+        break;
     case PROP_VCPU:
         gvir_config_domain_set_vcpus(domain, g_value_get_uint64(value));
         break;
@@ -152,6 +159,15 @@ static void gvir_config_domain_class_init(GVirConfigDomainClass *klass)
                                                         0,
                                                         G_PARAM_READWRITE |
                                                         G_PARAM_STATIC_STRINGS));
+    g_object_class_install_property(object_class,
+                                    PROP_CURRENT_MEMORY,
+                                    g_param_spec_uint64("current-memory",
+                                                        "Current memory",
+                                                        "Current Guest Memory (in kilobytes)",
+                                                        0, G_MAXUINT64,
+                                                        0,
+                                                        G_PARAM_READWRITE |
+                                                        G_PARAM_STATIC_STRINGS));
     g_object_class_install_property(object_class,
                                     PROP_VCPU,
                                     g_param_spec_uint64("vcpu",
@@ -275,39 +291,157 @@ const char *gvir_config_domain_get_description(GVirConfigDomain *domain)
  * @domain: a #GVirConfigDomain
  * @description: (allow-none):
  */
-void gvir_config_domain_set_description(GVirConfigDomain *domain, const char *description)
+void gvir_config_domain_set_description(GVirConfigDomain *domain,
+                                        const char *description)
 {
     gvir_config_object_set_node_content(GVIR_CONFIG_OBJECT(domain),
                                         "description", description);
     g_object_notify(G_OBJECT(domain), "description");
 }
 
+static void insert_base(GHashTable *unit_bases,
+                        const char *unit,
+                        guint64 unit_base)
+{
+    guint64 *base;
+    base = g_slice_alloc(sizeof(*base));
+    *base = unit_base;
+    g_hash_table_insert(unit_bases, (gpointer)unit, base);
+}
+
+static gpointer set_unit_bases(G_GNUC_UNUSED gpointer user_data)
+{
+    GHashTable *unit_bases;
+
+    unit_bases = g_hash_table_new(g_str_hash, g_str_equal);
+
+    insert_base(unit_bases, "b", 1);
+    insert_base(unit_bases, "bytes", 1);
+    insert_base(unit_bases, "KB", 1000);
+    insert_base(unit_bases, "k", 1024);
+    insert_base(unit_bases, "KiB", 1024);
+    insert_base(unit_bases, "MB", 1000*1000);
+    insert_base(unit_bases, "M", 1024*1024);
+    insert_base(unit_bases, "MiB", 1024*1024);
+    insert_base(unit_bases, "GB", 1000*1000*1000);
+    insert_base(unit_bases, "G", 1024*1024*1024);
+    insert_base(unit_bases, "GiB", 1024*1024*1024);
+    insert_base(unit_bases, "TB", (guint64)1000*1000*1000*1000);
+    insert_base(unit_bases, "T", (guint64)1024*1024*1024*1024);
+    insert_base(unit_bases, "TiB", (guint64)1024*1024*1024*1024);
+
+    return unit_bases;
+}
+
+static guint64 get_unit_base(const char *unit, guint64 default_base)
+{
+    static GOnce set_unit_bases_once = G_ONCE_INIT;
+    GHashTable *unit_bases;
+    guint64 *unit_base;
+
+    if (unit == NULL) {
+        return default_base;
+    }
+
+    unit_bases = g_once (&set_unit_bases_once, set_unit_bases, &unit_bases);
+    g_return_val_if_fail (unit_bases != NULL, default_base);
+
+    unit_base = g_hash_table_lookup(unit_bases, unit);
+    if (unit_base == NULL) {
+        /* unknown unit, fall back to the default unit */
+        g_return_val_if_reached(default_base);
+    }
+
+    return *unit_base;
+}
+
 /**
  * gvir_config_domain_get_memory:
  * @domain: a #GVirConfigDomain
  *
- * Returns: amount of RAM in kilobytes (i.e. blocks of 1024 bytes).
+ * Returns: maximum amount of RAM in kilobytes (i.e. blocks of 1024 bytes).
  */
 guint64 gvir_config_domain_get_memory(GVirConfigDomain *domain)
 {
-    return gvir_config_object_get_node_content_uint64(GVIR_CONFIG_OBJECT(domain),
-                                                      "memory");
+    const char *unit;
+    guint64 unit_base;
+    guint64 memory;
+
+    unit = gvir_config_object_get_attribute(GVIR_CONFIG_OBJECT(domain), "memory", "unit");
+    unit_base = get_unit_base(unit, 1024);
+
+    memory = gvir_config_object_get_node_content_uint64(GVIR_CONFIG_OBJECT(domain),
+                                                        "memory");
+
+    return memory * unit_base / 1024;
+}
+
+/**
+ * gvir_config_domain_get_current_memory:
+ * @domain: a #GVirConfigDomain
+ *
+ * Returns: current amount of RAM in kilobytes (i.e. blocks of 1024 bytes).
+ */
+guint64 gvir_config_domain_get_current_memory(GVirConfigDomain *domain)
+{
+    const char *unit;
+    guint64 unit_base;
+    guint64 memory;
+
+    unit = gvir_config_object_get_attribute(GVIR_CONFIG_OBJECT(domain), "currentMemory", "unit");
+    unit_base = get_unit_base(unit, 1024);
+
+    memory = gvir_config_object_get_node_content_uint64(GVIR_CONFIG_OBJECT(domain),
+                                                        "currentMemory");
+
+    return memory * unit_base / 1024;
 }
 
 /**
  * gvir_config_domain_set_memory:
  * @domain: a #GVirConfigDomain
- * @memory: The amount of RAM in kilobytes.
+ * @memory: The maximum amount of RAM in kilobytes.
  *
- * Sets the amount of RAM allocated to @domain in kilobytes (i.e. blocks of 1024 bytes).
+ * Sets the maximum amount of RAM allocated to @domain in kilobytes (i.e.
+ * blocks of 1024 bytes).
  */
 void gvir_config_domain_set_memory(GVirConfigDomain *domain, guint64 memory)
 {
-    gvir_config_object_set_node_content_uint64(GVIR_CONFIG_OBJECT(domain),
-                                               "memory", memory);
+    GVirConfigObject *node;
+
+    node = gvir_config_object_replace_child(GVIR_CONFIG_OBJECT(domain), "memory");
+    gvir_config_object_set_node_content_uint64(GVIR_CONFIG_OBJECT(node), NULL, memory);
+    gvir_config_object_set_attribute(GVIR_CONFIG_OBJECT(node),
+                                     "unit", "KiB",
+                                     NULL);
     g_object_notify(G_OBJECT(domain), "memory");
 }
 
+/**
+ * gvir_config_domain_set_current_memory:
+ * @domain: a #GVirConfigDomain
+ * @memory: The current amount of RAM in kilobytes.
+ *
+ * Sets the current amount of RAM allocated to @domain in kilobytes (i.e.
+ * blocks of 1024 bytes). This can be set to less than the maximum domain
+ * memory to allow to balloon the guest memory on the fly. Be aware that
+ * libvirt will set it automatically if it's not explictly set, which means
+ * you may need to set this value in addition to 'memory' if you want to
+ * change the available domain memory after creation.
+ */
+void gvir_config_domain_set_current_memory(GVirConfigDomain *domain,
+                                           guint64 memory)
+{
+    GVirConfigObject *node;
+
+    node = gvir_config_object_replace_child(GVIR_CONFIG_OBJECT(domain), "currentMemory");
+    gvir_config_object_set_node_content_uint64(GVIR_CONFIG_OBJECT(node), NULL, memory);
+    gvir_config_object_set_attribute(GVIR_CONFIG_OBJECT(node),
+                                     "unit", "KiB",
+                                     NULL);
+    g_object_notify(G_OBJECT(domain), "current-memory");
+}
+
 guint64 gvir_config_domain_get_vcpus(GVirConfigDomain *domain)
 {
     return gvir_config_object_get_node_content_uint64(GVIR_CONFIG_OBJECT(domain),
@@ -670,3 +804,19 @@ void gvir_config_domain_set_cpu(GVirConfigDomain *domain,
                                       "cpu",
                                       GVIR_CONFIG_OBJECT(cpu));
 }
+
+/**
+ * gvir_config_domain_set_power_management:
+ * @domain: a #GVirConfigDomain
+ * @pm: (allow-none): a #GVirPowerManagement instance
+ */
+void gvir_config_domain_set_power_management(GVirConfigDomain *domain,
+                                             GVirConfigDomainPowerManagement *pm)
+{
+    g_return_if_fail(GVIR_CONFIG_IS_DOMAIN(domain));
+    g_return_if_fail(pm != NULL || GVIR_CONFIG_IS_DOMAIN_POWER_MANAGEMENT(pm));
+
+    gvir_config_object_attach_replace(GVIR_CONFIG_OBJECT(domain),
+                                      "pm",
+                                      GVIR_CONFIG_OBJECT(pm));
+}
