@@ -15,8 +15,8 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
+ * License along with this library. If not, see
+ * <http://www.gnu.org/licenses/>.
  *
  * Author: Daniel P. Berrange <berrange@redhat.com>
  */
@@ -59,6 +59,8 @@ void gvir_set_error_valist(GError **error,
                            const gchar *format,
                            va_list args);
 
+void gvir_critical(const gchar *format, ...);
+void gvir_warning(const gchar *format, ...);
 
 G_END_DECLS
 
