@@ -15,8 +15,8 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
+ * License along with this library. If not, see
+ * <http://www.gnu.org/licenses/>.
  *
  * Author: Daniel P. Berrange <berrange@redhat.com>
  */
@@ -164,7 +164,7 @@ const gchar *gvir_interface_get_name(GVirInterface *iface)
     g_return_val_if_fail(GVIR_IS_INTERFACE(iface), NULL);
 
     if (!(name = virInterfaceGetName(iface->priv->handle))) {
-        g_warning("Failed to get interface name on %p", iface->priv->handle);
+        gvir_warning("Failed to get interface name on %p", iface->priv->handle);
         return NULL;
     }
 
