@@ -15,8 +15,8 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
+ * License along with this library. If not, see
+ * <http://www.gnu.org/licenses/>.
  *
  * Author: Daniel P. Berrange <berrange@redhat.com>
  */
@@ -164,8 +164,8 @@ const gchar *gvir_node_device_get_name(GVirNodeDevice *device)
     g_return_val_if_fail(GVIR_IS_NODE_DEVICE(device), NULL);
 
     if (!(name = virNodeDeviceGetName(device->priv->handle))) {
-        g_warning("Failed to get node_device name on %p",
-                  device->priv->handle);
+        gvir_warning("Failed to get node_device name on %p",
+                     device->priv->handle);
         return NULL;
     }
 
